Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/editors/object/object_hook.c')
-rw-r--r--source/blender/editors/object/object_hook.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/blender/editors/object/object_hook.c b/source/blender/editors/object/object_hook.c
index 2cfefa61a18..6a41cb93e19 100644
--- a/source/blender/editors/object/object_hook.c
+++ b/source/blender/editors/object/object_hook.c
@@ -417,13 +417,13 @@ static Object *add_hook_object_new(Scene *scene, Object *obedit)
Base *base, *basedit;
Object *ob;
- ob = add_object(scene, OB_EMPTY);
+ ob = BKE_object_add(scene, OB_EMPTY);
basedit = object_in_scene(obedit, scene);
base = object_in_scene(ob, scene);
base->lay = ob->lay = obedit->lay;
/* icky, add_object sets new base as active.
* so set it back to the original edit object */
scene->basact = basedit;
@@ -469,7 +469,7 @@ static void add_hook_object(Main *bmain, Scene *scene, Object *obedit, Object *o
/* matrix calculus */
/* vert x (obmat x hook->imat) x hook->obmat x ob->imat */
/* (parentinv ) */
- where_is_object(scene, ob);
+ BKE_object_where_is_calc(scene, ob);
invert_m4_m4(ob->imat, ob->obmat);
/* apparently this call goes from right to left... */
@@ -417,13 +417,13 @@ static Object *add_hook_object_new(Scene *scene, Object *obedit)
base = object_in_scene(ob, scene);
base->lay = ob->lay = obedit->lay;
- /* icky, add_object sets new base as active.
+ /* icky, BKE_object_add sets new base as active.
* so set it back to the original edit object */
scene->basact = basedit;